@@ -6,12 +6,12 @@
 
 use strict;
 use warnings;
-use v5.18.0; # require 2014 or newer version of Perl
+use v5.14.0; # require 2011 or newer version of Perl
 
 # State class to hold program state, and print it all out in case of errors
 # this is a low-level package - it stores state data but at this level has no knowledge of what is being stored in it
 package PiFlash::State;
-$PiFlash::State::VERSION = '0.2.1';
+$PiFlash::State::VERSION = '0.2.2';
 use autodie;
 use YAML::XS; # RPM: perl-YAML-LibYAML, DEB: libyaml-libyaml-perl
 use Carp qw(croak);
@@ -95,7 +95,13 @@ sub verbose
 	return PiFlash::State::cli_opt("verbose") // 0;
 }
 
-# dump data structure recursively, part of verbose state output
+# return boolean value for logging mode (recording run data without printing verbose messages, intended for testing)
+sub logging
+{
+	return PiFlash::State::cli_opt("logging") // 0;
+}
+
+# dump data structure recursively, part of verbose/logging state output
 # intended as a lightweight equivalent of Data::Dumper without requiring installation of an extra package
 # object method
 sub odump
@@ -154,7 +160,8 @@ sub error
 	## no critic (ProhibitPackageVars)
 	my $class = shift;
 	my $message = shift;
-	croak "error: ".$message.(verbose() ? "\nProgram state dump...\n".odump($PiFlash::State::state,0) : "");
+	croak "error: ".$message.((verbose() or logging())
+		? "\nProgram state dump...\n".odump($PiFlash::State::state,0) : "");
 }
 
 # read YAML configuration file
@@ -217,7 +224,7 @@ PiFlash::State - PiFlash::State class to store configuration, device info and pr
 
 =head1 VERSION
 
-version 0.2.1
+version 0.2.2
 
 =head1 SYNOPSIS
 
@@ -229,7 +236,8 @@ version 0.2.1
  PiFlash::State->init(@categories);
 
  # core functions
- $bool = PiFlash::State::verbose()
+ $bool_verbose_mode = PiFlash::State::verbose()
+ $bool_logging_mode = PiFlash::State::logging()
  PiFlash::State::odump
  PiFlash::State->error("error message");
 
